[][src]Struct cloudflare_rs::endpoints::workers::WorkersRoute

pub struct WorkersRoute {
    pub id: String,
    pub pattern: String,
    pub script: Option<String>,
}

Workers KV Route Routes are basic patterns used to enable or disable workers that match requests. https://api.cloudflare.com/#worker-routes-properties

Fields

id: String

Namespace identifier tag.

pattern: String

The basic pattern that should map to the script

script: Option<String>

Name of the script to apply when the route is matched. The route is skipped when this is blank/missing.