[][src]Struct cloudflare_rs::endpoints::zone::Meta

pub struct Meta {
    pub custom_certificate_quota: u32,
    pub page_rule_quota: u32,
    pub wildcard_proxiable: bool,
    pub phishing_detected: bool,
    pub multiple_railguns_allowed: bool,
}

Fields

custom_certificate_quota: u32

Maximum custom certificates that can be uploaded/used.

page_rule_quota: u32

Maximum page rules that can be created.

wildcard_proxiable: bool

Indicates whether wildcard DNS records can receive Cloudflare security and performance features

phishing_detected: bool

Indicates if URLs on the zone have been identified as hosting phishing content.

multiple_railguns_allowed: bool

Indicates whether the zone is allowed to be connected to multiple Railguns at once