[−][src]Struct cloudflare_rs::endpoints::zone::Zone
A Zone is a domain name along with its subdomains and other identities https://api.cloudflare.com/#zone-properties
Fields
id: StringZone identifier tag
name: StringThe domain name
account: AccountInformation about the account the zone belongs to
betas: Option<Vec<String>>A list of beta features in which the zone is participating
created_on: DateTime<Utc>When the zone was created
deactivation_reason: Option<String>Exists only with a deactivated status and indicates the reason the zone is not resolving on the Cloudflare network.
development_mode: i32The interval (in seconds) from when development mode expires (positive integer) or last expired (negative integer) for the domain. If development mode has never been enabled, this value is 0.
host: Option<HostingPartner>Hosting partner information, if the zone signed up via a Cloudflare hosting partner
meta: MetaMetadata about the domain.
modified_on: DateTime<Utc>When the zone was last modified
name_servers: Vec<String>Cloudflare-assigned name servers. This is only populated for zones that use Cloudflare DNS
original_dnshost: Option<String>DNS host at the time of switching to Cloudflare
original_name_servers: Option<Vec<String>>Original name servers before moving to Cloudflare
original_registrar: Option<String>Registrar for the domain at the time of switching to Cloudflare
owner: OwnerInformation about the owner of the zone
paused: boolIndicates if the zone is only using Cloudflare DNS services. A true value means the zone will not receive security or performance benefits.
permissions: Vec<String>Available permissions on the zone for the current user requesting the item
plan: Option<Plan>A zone plan
plan_pending: Option<Plan>A zone plan
status: StatusStatus of the zone
zone_type: TypeA full zone implies that DNS is hosted with Cloudflare. A partial zone is typically a partner-hosted zone or a CNAME setup.