[−][src]Struct cloudflare_rs::framework::HttpApiClientConfig
Configuration for the API client. Allows users to customize its behaviour.
Fields
http_timeout: DurationThe maximum time limit for an API request. If a request takes longer than this, it will be cancelled.
default_headers: HeaderMapA default set of HTTP headers which will be sent with each API request.