[−][src]Struct cloudflare_rs::endpoints::load_balancing::Origin
An origin represents something that can serve user requests. Usually a machine, maybe an ELB. Origins with similar latency functions (e.g. origins in the same data center or region) might be in the same pool.
Fields
name: StringA human-identifiable name for the origin. e.g. app-server-1
address: IpAddrThe IP address (IPv4 or IPv6) of the origin, or the publicly addressable hostname. Hostnames entered here should resolve directly to the origin, and not be a hostname proxied by Cloudflare. e.g. 0.0.0.0
enabled: boolWhether to enable (the default) this origin within the Pool. Disabled origins will not receive traffic and are excluded from health checks. The origin will only be disabled for the current pool.
weight: f64The weight of this origin relative to other origins in the Pool. Based on the configured weight the total traffic is distributed among origins within the Pool.